chembl_webresource_client
======

This is chembl_webresource_client package developed at Chembl group, EMBL-EBI, Cambridge, UK.

This package implements python client for accessing ChEMBL webservices.
It provides convenient interface to access data, cache results and optionally executes requests in asynchronous manner.
